import { __assign } from "tslib";
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
import { Amplify, CookieStorage, defaultStorage, } from '@aws-amplify/core';
import { parseAWSExports, } from '@aws-amplify/core/internals/utils';
import { CognitoUserPoolsTokenProvider, cognitoCredentialsProvider, } from './auth/cognito';
export var DefaultAmplify = {
    configure: function (resourceConfig, libraryOptions) {
        var resolvedResourceConfig;
        if (Object.keys(resourceConfig).some(function (key) { return key.startsWith('aws_'); })) {
            resolvedResourceConfig = parseAWSExports(resourceConfig);
        }
        else {
            resolvedResourceConfig = resourceConfig;
        }
        // When Auth config is provided but no custom Auth provider defined
        // use the default Auth Providers
        if (resolvedResourceConfig.Auth && !(libraryOptions === null || libraryOptions === void 0 ? void 0 : libraryOptions.Auth)) {
            CognitoUserPoolsTokenProvider.setAuthConfig(resolvedResourceConfig.Auth);
            var libraryOptionsWithDefaultAuthProviders = __assign(__assign({}, libraryOptions), { Auth: {
                    tokenProvider: CognitoUserPoolsTokenProvider,
                    credentialsProvider: cognitoCredentialsProvider,
                } });
            CognitoUserPoolsTokenProvider.setKeyValueStorage((libraryOptions === null || libraryOptions === void 0 ? void 0 : libraryOptions.ssr)
                ? new CookieStorage({
                    sameSite: 'strict',
                })
                : defaultStorage);
            Amplify.configure(resolvedResourceConfig, libraryOptionsWithDefaultAuthProviders);
        }
        else {
            Amplify.configure(resolvedResourceConfig, libraryOptions);
        }
    },
    getConfig: function () {
        return Amplify.getConfig();
    },
};
